@@ -1,26 +1,21 @@
+# -*- coding: utf-8 -*-
 # Example package with a console entry point
 """Reads and formats data from the SWMM 5 output file."""
 
-from __future__ import absolute_import
-from __future__ import print_function
+from __future__ import absolute_import, print_function
 
-from builtins import object
-from builtins import range
-from builtins import str
-from builtins import zip
 import copy
 import datetime
 import os
 import struct
 import sys
 import warnings
+from builtins import object, range, str, zip
 
 import mando
-from mando.rst_text_formatter import RSTHelpFormatter
-
 import numpy as np
 import pandas as pd
-
+from mando.rst_text_formatter import RSTHelpFormatter
 from tstoolbox import tsutils
 
 PROPCODE = {
